@@ -20,12 +20,18 @@ class AsyncTests: XCTestCase {
         await rust_async_return_null()
     }
    
-    /// Verify that we can call async Rust functions
+    /// Verify that we can pass and return a u8 to an async Rust function
     func testSwiftCallsRustAsyncFnReflectU8() async throws {
         let num = await rust_async_reflect_u8(123)
         XCTAssertEqual(num, 123)
     }
     
+     /// Verify that we can pass and return a String to an async Rust function
+    func testSwiftCallsRustAsyncFnReflectString() async throws {
+        let string = await rust_async_reflect_string("hello world")
+        XCTAssertEqual(string.toString(), "hello world")
+    }
+    
     /// Verify that we can call async Rust methods
     func testSwiftCallsRustAsyncMethodReflectU16() async throws {
         let test = TestRustAsyncSelf()
@@ -39,3 +45,4 @@ class AsyncTests: XCTestCase {
         let _: AsyncRustFnReturnStruct = await rust_async_return_struct()
     }
 }
+
